<?php
/**
 * Firmbee Job Search functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Firmbee_Lets_Start
 */

define('BOOTSTRAP_VERSION', '5.0.2');

if ( ! function_exists( 'firmbee_lets_start_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function firmbee_lets_start_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Firmbee Job Search, use a find and replace
		 * to change 'firmbee-lets-start' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'firmbee-lets-start', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(array('primary' => 'Primary Navigation','footer_menu'  => 'Footer Menu','footer_usefull_links'  => 'Footer Useful links'));

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'firmbee_lets_start_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'width'       => 120,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'firmbee_lets_start_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function firmbee_lets_start_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'firmbee_lets_start_content_width', 640 );
}
add_action( 'after_setup_theme', 'firmbee_lets_start_content_width', 0 );



/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */


function register_widget_areas() {

	register_sidebar( array(
	  'name'          => 'Copyright footer',
	  'id'            => 'copyright-footer',
	  'description'   => 'adding copyright text',
	  'before_sidebar' => ' <div clas="copyright">',
	  'before_sidebar'  => '</div>',
	));

	register_sidebar( array(
		'name'          => 'About company footer',
		'id'            => 'about-company-footer',
		'description'   => 'Adding about company information and social media links in the first footer column',
		'before_sidebar' => ' <div class="about">',
		'after_sidebar'  => '</div>',

	  )); 


	  register_sidebar( array(
		'name'          => 'Newsletter',
		'id'            => 'newsletter',
		'description'   => 'Forth footer column',
		'before_sidebar' => ' <div class="newsletter"><h6>Newsletter</h6>',
		'after_sidebar'  => '</div>',
	  ));	  
	
  }
  
  add_action( 'widgets_init', 'register_widget_areas' );


/**
 * Enqueue scripts and styles.
 */
function firmbee_lets_start_scripts() {
	wp_enqueue_style( 'firmbee-lets-start-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_style_add_data( 'firmbee-lets-start-style', 'rtl', 'replace' );


	wp_register_script('bootstrap', get_template_directory_uri() . '/js/bootstrap.bundle.min.js', array( 'jquery' ), BOOTSTRAP_VERSION, true);
	wp_enqueue_script('bootstrap');

	wp_register_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', array(), BOOTSTRAP_VERSION, 'all' );
	wp_enqueue_style( 'bootstrap' );

	wp_register_style( 'main', get_template_directory_uri() . '/css/main.css', array(), 1.0, 'all' );
	wp_enqueue_style( 'main' );

	wp_register_style( 'front-page', get_template_directory_uri() . '/css/front-page.css', array(), 1.0, 'all' );
	wp_enqueue_style( 'front-page' );

	wp_register_script( 'fontawesome', "https://kit.fontawesome.com/0e035b9984.js", array(), 1.0, 'all' );
	wp_enqueue_script( 'fontawesome' );
	

	

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'firmbee_lets_start_scripts' );

/**
 * Enqueue Google Fonts
 */

function google_fonts() {
	wp_enqueue_style( 'google-fonts', 'https://fonts.googleapis.com/css2?family=Lato:wght@400;700;900&display=swap', false );
	wp_enqueue_style( 'google-fonts-header', 'https://fonts.googleapis.com/css2?family=Fredoka+One&family=Open+Sans&display=swap', false );
}
add_action( 'wp_enqueue_scripts', 'google_fonts' );


/**
 * Enqueue Adobe Fonts
 */

function adobe_fonts() {
	wp_enqueue_style( 'adobe-fonts', 'https://use.typekit.net/rrg4put.css', false );
}

add_action( 'wp_enqueue_scripts', 'adobe_fonts' );

/**
 * Required external files
 */

require_once( 'external/bootstrap-utilities.php' );
require_once( 'external/bs5navwalker.php' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Comment Form Placeholder Author, Email, URL
 */
function placeholder_author_email_url_form_fields($fields) {
    $replace_author = __('Name*', 'yourfirmbee_lets_start');
    $replace_email = __('Email Address*', 'firmbee_lets_start');
    $replace_url = __('Your Website', 'firmbee_lets_start');
    
    $fields['author'] = '<p class="comment-form-author">' . ( $req ? '<span class="required">*</span>' : '' ) .
                    '<input id="author" name="author" type="text" placeholder="'.$replace_author.'" value="' . esc_attr( $commenter['comment_author'] ) . '" size="20"' . $aria_req . ' /></p>';
                    
    $fields['email'] = '<p class="comment-form-email">'.
    ( $req ? '<span class="required">*</span>' : '' ) .
    '<input id="email" name="email" type="text" placeholder="'.$replace_email.'" value="' . esc_attr(  $commenter['comment_author_email'] ) .
    '" size="30"' . $aria_req . ' /></p>';
    
    $fields['url'] = '<p class="comment-form-url">'.
    '<input id="url" name="url" type="text" placeholder="'.$replace_url.'" value="' . esc_attr( $commenter['comment_author_url'] ) .
    '" size="30" /></p>';
    
    return $fields;
}
add_filter('comment_form_default_fields','placeholder_author_email_url_form_fields');



/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}


